@@ -1052,7 +1052,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	    while (attr != NULL) {
 		if (attr->defaultValue != NULL) {
 		    /*
-		     * the element should be instanciated in the tree if:
+		     * the element should be instantiated in the tree if:
 		     *  - this is a namespace prefix
 		     *  - the user required for completion in the tree
 		     *    like XSLT
@@ -1062,14 +1062,14 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 		        ((attr->prefix == NULL) &&
 			 (xmlStrEqual(attr->name, BAD_CAST "xmlns"))) ||
 			(ctxt->loadsubset & XML_COMPLETE_ATTRS)) {
-			xmlChar buffer[100];
-			const xmlChar *fulln = attr->name;
+			xmlChar *fulln;
 
 			if (attr->prefix != NULL) {
-			    snprintf((char *) buffer, 99, "%s:%s",
-				     attr->prefix, attr->name);
-			    buffer[99] = 0;
-			    fulln = buffer;
+			    fulln = xmlStrdup(attr->prefix);
+			    fulln = xmlStrcat(fulln, BAD_CAST ":");
+			    fulln = xmlStrcat(fulln, attr->name);
+			} else {
+			    fulln = xmlStrdup(attr->name);
 			}
 
 			/*
@@ -1089,6 +1089,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 			}
 			if (att == NULL)
 			    attribute(ctxt, fulln, attr->defaultValue);
+			xmlFree(fulln);
 		    }
 		}
 		attr = attr->nexth;
@@ -1163,7 +1164,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
     }
 
     /*
-     * If it's the Document root, finish the Dtd validation and
+     * If it's the Document root, finish the DTD validation and
      * check the document root element for validity
      */
     if ((ctxt->validate) && (ctxt->vctxt.finishDtd == 0)) {
@@ -1661,9 +1662,11 @@ cdataBlock(void *ctx, const xmlChar *value, int len)
 }
 
 /**
- * xmlDefaultSAXHandlerInit:
+ * initxmlDefaultSAXHandler:
+ * @hdlr:  the SAX handler
+ * @warning:  flag if non-zero sets the handler warning procedure
  *
- * Initialize the default SAX handler
+ * Initialize the default XML SAX handler
  */
 void
 initxmlDefaultSAXHandler(xmlSAXHandler *hdlr, int warning)
@@ -1720,9 +1723,10 @@ xmlDefaultSAXHandlerInit(void)
 #ifdef LIBXML_HTML_ENABLED
 
 /**
- * htmlDefaultSAXHandlerInit:
+ * inithtmlDefaultSAXHandler:
+ * @hdlr:  the SAX handler
  *
- * Initialize the default SAX handler
+ * Initialize the default HTML SAX handler
  */
 void
 inithtmlDefaultSAXHandler(xmlSAXHandler *hdlr)
@@ -1776,6 +1780,12 @@ htmlDefaultSAXHandlerInit(void)
 
 #ifdef LIBXML_DOCB_ENABLED
 
+/**
+ * initdocbDefaultSAXHandler:
+ * @hdlr:  the SAX handler
+ *
+ * Initialize the default DocBook SAX handler
+ */
 void
 initdocbDefaultSAXHandler(xmlSAXHandler *hdlr)
 {
