@@ -19,8 +19,6 @@
 #else
 #include <libxml/xmlversion.h>
 #endif
-#include <libxml/xmlmemory.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -42,6 +40,21 @@ typedef xmlParserInput *xmlParserInputPtr;
 typedef struct _xmlParserCtxt xmlParserCtxt;
 typedef xmlParserCtxt *xmlParserCtxtPtr;
 
+typedef struct _xmlSAXLocator xmlSAXLocator;
+typedef xmlSAXLocator *xmlSAXLocatorPtr;
+
+typedef struct _xmlSAXHandler xmlSAXHandler;
+typedef xmlSAXHandler *xmlSAXHandlerPtr;
+
+/* entities.h */
+typedef struct _xmlEntity xmlEntity;
+typedef xmlEntity *xmlEntityPtr;
+
+/**
+ * BASE_BUFFER_SIZE:
+ *
+ * default buffer size 4000
+ */
 #define BASE_BUFFER_SIZE 4000
 
 /**
@@ -207,7 +220,7 @@ typedef enum {
 /**
  * xmlElementContentOccur:
  *
- * Possible definitions of element content occurences
+ * Possible definitions of element content occurrences
  */
 typedef enum {
     XML_ELEMENT_CONTENT_ONCE = 1,
@@ -238,7 +251,7 @@ struct _xmlElementContent {
 /**
  * xmlElementTypeVal:
  *
- * the differnt possibility for an element content type
+ * the different possibilities for an element content type
  */
 
 typedef enum {
@@ -288,7 +301,7 @@ typedef xmlElementType xmlNsType;
  *
  * An XML namespace.
  * Note that prefix == NULL is valid, it defines the default namespace
- * within the subtree (until overriden).
+ * within the subtree (until overridden).
  *
  * xmlNsType is unified with xmlElementType
  */
@@ -305,7 +318,7 @@ struct _xmlNs {
 /**
  * xmlDtd:
  *
- * An XML DtD, as defined by <!DOCTYPE ... There is actually one for
+ * An XML DTD, as defined by <!DOCTYPE ... There is actually one for
  * the internal subset and for the external subset
  */
 typedef struct _xmlDtd xmlDtd;
@@ -363,7 +376,7 @@ typedef xmlID *xmlIDPtr;
 struct _xmlID {
     struct _xmlID    *next;	/* next ID */
     const xmlChar    *value;	/* The ID name */
-    xmlAttrPtr        attr;	/* The attribut holding it */
+    xmlAttrPtr        attr;	/* The attribute holding it */
 };
 
 /**
@@ -377,7 +390,7 @@ typedef xmlRef *xmlRefPtr;
 struct _xmlRef {
     struct _xmlRef    *next;	/* next Ref */
     const xmlChar     *value;	/* The Ref name */
-    xmlAttrPtr        attr;	/* The attribut holding it */
+    xmlAttrPtr        attr;	/* The attribute holding it */
 };
 
 /**
@@ -423,14 +436,14 @@ struct _xmlNode {
     struct _xmlNode *next;	/* next sibling link  */
     struct _xmlNode *prev;	/* previous sibling link  */
     struct _xmlDoc  *doc;	/* the containing document */
+
+    /* End of common part */
     xmlNs           *ns;        /* pointer to the associated namespace */
 #ifndef XML_USE_BUFFER_CONTENT    
     xmlChar         *content;   /* the content */
 #else
     xmlBufferPtr     content;   /* the content in a buffer */
 #endif
-
-    /* End of common part */
     struct _xmlAttr *properties;/* properties list */
     xmlNs           *nsDef;     /* namespace definitions on this node */
 };
@@ -507,12 +520,13 @@ struct _xmlDoc {
 /*
  * Variables.
  */
-LIBXML_DLL_IMPORT extern xmlNsPtr baseDTD;
+#if 0
 LIBXML_DLL_IMPORT extern int oldXMLWDcompatibility;/* maintain compatibility with old WD */
 LIBXML_DLL_IMPORT extern int xmlIndentTreeOutput;  /* try to indent the tree dumps */
 LIBXML_DLL_IMPORT extern xmlBufferAllocationScheme xmlBufferAllocScheme; /* alloc scheme to use */
 LIBXML_DLL_IMPORT extern int xmlSaveNoEmptyTags; /* save empty tags as <empty></empty> */
 LIBXML_DLL_IMPORT extern int xmlDefaultBufferSize; /* default buffer size */
+#endif
 
 /*
  * Handling Buffers.
@@ -643,6 +657,8 @@ xmlNodePtr	xmlNewDocFragment	(xmlDocPtr doc);
 /*
  * Navigating
  */
+long		xmlGetLineNo		(xmlNodePtr node);
+xmlChar *	xmlGetNodePath		(xmlNodePtr node);
 xmlNodePtr	xmlDocGetRootElement	(xmlDocPtr doc);
 xmlNodePtr	xmlGetLastChild		(xmlNodePtr parent);
 int		xmlNodeIsText		(xmlNodePtr node);
@@ -742,8 +758,8 @@ xmlChar *	xmlNodeGetLang		(xmlNodePtr cur);
 void		xmlNodeSetLang		(xmlNodePtr cur,
 					 const xmlChar *lang);
 int		xmlNodeGetSpacePreserve	(xmlNodePtr cur);
-void		xmlNodeSetSpacePreserve (xmlNodePtr cur, int
-					 val);
+void		xmlNodeSetSpacePreserve (xmlNodePtr cur,
+					 int val);
 xmlChar *	xmlNodeGetBase		(xmlDocPtr doc,
 					 xmlNodePtr cur);
 void		xmlNodeSetBase		(xmlNodePtr cur,
@@ -752,7 +768,7 @@ void		xmlNodeSetBase		(xmlNodePtr cur,
 /*
  * Removing content.
  */
-int		xmlRemoveProp		(xmlAttrPtr attr);
+int		xmlRemoveProp		(xmlAttrPtr cur);
 int		xmlUnsetProp		(xmlNodePtr node,
 					 const xmlChar *name);
 int		xmlUnsetNsProp		(xmlNodePtr node,
@@ -785,11 +801,11 @@ int		xmlReconciliateNs	(xmlDocPtr doc,
  * Saving
  */
 void		xmlDocDumpFormatMemory	(xmlDocPtr cur,
-					 xmlChar**mem,
+					 xmlChar **mem,
 					 int *size,
 					 int format);
 void		xmlDocDumpMemory	(xmlDocPtr cur,
-					 xmlChar**mem,
+					 xmlChar **mem,
 					 int *size);
 void		xmlDocDumpMemoryEnc	(xmlDocPtr out_doc,
 					 xmlChar **doc_txt_ptr,
@@ -830,10 +846,10 @@ void		xmlNodeDumpOutput	(xmlOutputBufferPtr buf,
 					 int format,
 					 const char *encoding);
 
-int		xmlSaveFormatFileEnc    ( const char * filename,
-					  xmlDocPtr cur,
-					  const char * encoding,
-					  int format );
+int		xmlSaveFormatFileEnc    (const char *filename,
+					 xmlDocPtr cur,
+					 const char *encoding,
+					 int format);
 
 int		xmlSaveFileEnc		(const char *filename,
 					 xmlDocPtr cur,
@@ -851,6 +867,9 @@ void		xmlSetCompressMode	(int mode);
 #ifdef __cplusplus
 }
 #endif
+#ifndef __XML_PARSER_H__
+#include <libxml/xmlmemory.h>
+#endif
 
 #endif /* __XML_TREE_H__ */
 
